``packs`` key - Enable pre-configured packs
===========================================

The OU Container Builder provides pre-configured packs that simplify the setup of common scenarios. Packs are always
configured via the top-level ``packs`` key:

.. code:: yaml

    packs:
      - name:     # Name of the pack
        options:  # Pack-specific options

Details on the available packs is :doc:`available here <../packs/index>`.
